# SPDX-License-Identifier: GPL-3.0-or-later


## License

All files in this directory are licensed under GPL-3.0-or-later `LICENSES/GPL-3.0-or-later.txt`.


- SPDX-License-Identifier: GPL-3.0-or-later
